TiniAI is a tiny AI written by me, that give answer from .json train file.

.json TRAIN FILE CONFIGURE
Create .json file and write train info like this:

{
    "How much we need for platinum?": ["Platine? Thirty"]
}

Use it in your projects. You can write a library to write large .json train file with your questions and answers.